%include common-macros.specinclude

Summary: The Samba SMB server.
Name: lsb-samba
Version: 3.5.9
Release: 5.lsb5
Vendor: Linux Foundation
Packager: LSB project team <lsb-discuss@linuxfoundation.org>
License: GPL
Group: Appbat/servers
Buildroot: %{_tmppath}/%{name}-root
AutoReqProv: no
Requires: lsb >= 5.0
BuildRequires: lsb-build-libbat-%{appbatversion}
BuildRequires: lsb-build-cc

Source0: http://us1.samba.org/samba/ftp/samba-%{version}.tar.gz
Patch0: samba-%{version}.patch
Patch1: samba-%{version}.lsb5.patch

%description
LSB conforming version of samba.  Samba provides an SMB server that
can be used to provide network services to SMB (sometimes called "Lan
Manager") clients. Samba uses NetBIOS over TCP/IP (NetBT) protocols
and does NOT need the NetBEUI (Microsoft Raw NetBIOS frame) protocol.
Samba is added to the LSB Application Battery primarly to demonstrate
the use of networking and of PAM-based authentication.

%prep
%setup -q -n samba-%{version}
%patch0 -p1 -b .lsbcc
%patch1 -p0 -b .lsb5

%build
# bail if tdb-devel is installed, things totally fall apart then
if [ -f /usr/include/tdb.h ];then
  echo "Found /usr/include/tdb.h, this build will most likely fail"
  echo "Please uninstall the package that provides this file"
  exit 1
fi

# common environment settings
export LSBCC_LSBVERSION=%{appbatversion}
%define prefix /opt/lsb
%define app_prefix %{prefix}/appbat
%define bindir %{app_prefix}/bin
%define sharedir %{app_prefix}/share
%define mandir %{app_prefix}/man

%ifarch s390x ppc64 x86_64
%define lib lib64
%else
%define lib lib
%endif
%define libdir %{prefix}/%{lib}
%define includedir %{prefix}/include

# need to be able to align with the LSB/libbat version we're built for
export CC="lsbcc -L/opt/lsb/libbat/%{appbatversion}/%{lib} -I/opt/lsb/libbat/%{appbatversion}/include"
export CXX="lsbc++ -L/opt/lsb/libbat/%{appbatversion}/%{lib} -I/opt/lsb/libbat/%{appbatversion}/include"
%define libdir %{prefix}/%{lib}-%{appbatversion}
export PKG_CONFIG_PATH=%{libdir}/pkgconfig:/opt/lsb/libbat/%{appbatversion}/%{lib}/pkgconfig
export PATH=/opt/lsb/libbat/%{appbatversion}/bin:${PATH}

# FIXME - force pam - what's really happening is we're using part of the 
# system pam headers, as LSB doesn't have pam_modules.h
export CFLAGS=-DLINUX_PAM

# set following four environment variables to avoid using aio and prctl
export ac_cv_header_aio=no
export ac_cv_header_aio_h=no
export ac_cv_header_sys_prctl=no
export ac_cv_header_sys_prctl_h=no

# LSB does not have getifaddr/freeifaddr. This did not seem to work, see patched replace.h
export libreplace_cv_HAVE_GETIFADDRS=yes
export samba_cv_REPLACE_GETPASS=yes

# set this variable for pam headers to work correctly
export ac_cv_header_security_pam_modules_h=yes

# 64bit fcntl locks do not work everywhere
export samba_cv_HAVE_BROKEN_FCNTL64_LOCKS=yes

export samba_cv_HAVE_OFF64_T=no

cd source3
./configure \
    --disable-cups \
    --prefix=%{app_prefix} \
    --localstatedir=/var/opt/lsb/appbat \
    --with-configdir=/etc/opt/lsb/appbat \
    --with-privatedir=/etc/opt/lsb/appbat \
    --enable-external-libtdb=no \
    --with-pam \
    --without-pam_smbpass \
    --without-winbind \
    --without-cifsmount \
    --without-ldap \
    --without-sys-quotas \
    --without-libtalloc \
    --with-static-libs=libwbclient

make

%install
rm -rf %{buildroot}

cd source3
make DESTDIR=%{buildroot} install

install -d %{buildroot}/etc/opt/lsb/appbat
chmod 0755 %{buildroot}/var/opt/lsb/appbat/locks

# this builds but is not compliant - drop it
# libaddns also, but it does not install
find %{buildroot} -name pam_winbind* | xargs rm -f

# drop these docs
rm -fr %{buildroot}%{app_prefix}/swat

# we used to have the user create this in the FVT, why not just provide it?
cat > %{buildroot}/etc/opt/lsb/appbat/smb.conf << EOF
[global]
        workgroup = WORKGROUP
        interfaces = eth0

[homes]
        guest ok = no
        read only = no
EOF

# make a README about the patch
COUNT=`grep -n '\-\-\-' %{PATCH0} | head -1 | awk -F\: '{print $1}'`
if [ "$COUNT" -gt 1 ];then
  COUNT=`expr $COUNT - 1`
  install -d %{buildroot}%{sharedir}/doc
  head -"$COUNT" %{PATCH0} > %{buildroot}%{sharedir}/doc/README.LSB.samba.build.patches 
fi

%pre

%post

%preun

%postun

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%dir /etc/opt/lsb
%dir /var/opt/lsb

%attr ( -   root root ) /opt/lsb/appbat
%attr ( -   root root ) /var/opt/lsb/appbat
%attr ( -   root root ) /etc/opt/lsb/appbat

%changelog
* Thu Jun 16 2011 Stew Benedict <stewb@linux-foundation.org>
- uplift to 3.5.9
- rediff P0 - rework pam mangling, drop SMB_OFF_T stuff, add IOV_MAX
- disable pam_smbpass, winbind (uses pam_get_user, pam_set_data)
- bail if tdb-devel is installed, things totally fall apart then

* Fri May 13 2011 Stew Benedict <stewb@linux-foundation.org>
- use spec file to build, drop nALFS, add conf

* Fri Feb 25 2011 Stew Benedict <stewb@linux-foundation.org>
- own the dirs we populate (bug 3195)
